package sun.nio.fs;

import java.util.Map;
import java.io.IOException;
import java.nio.file.LinkOption;
import java.nio.file.Path;
import java.nio.file.spi.FileSystemProvider;

abstract class AbstractFileSystemProvider extends FileSystemProvider
{
    protected AbstractFileSystemProvider() {
    }
    
    private static String[] split(String s) {
        String[] array = new String[2];
        int index = s.indexOf(58);
        if (index == -1) {
            array[0] = "basic";
            array[1] = s;
            return array;
        }
        array[0] = s.substring(0, index++);
        array[1] = ((index == s.length()) ? "" : s.substring(index));
        return array;
    }
    
    abstract DynamicFileAttributeView getFileAttributeView(Path p0, String p1, LinkOption... p2);
    
    @Override
    public final void setAttribute(Path path, String s, Object o, LinkOption... array) throws IOException {
        String[] split = split(s);
        if (split[0].length() == 0) {
            throw new IllegalArgumentException(s);
        }
        DynamicFileAttributeView fileAttributeView = this.getFileAttributeView(path, split[0], array);
        if (fileAttributeView == null) {
            throw new UnsupportedOperationException("View '" + split[0] + "' not available");
        }
        fileAttributeView.setAttribute(split[1], o);
        return;
    }
    
    @Override
    public final Map<String, Object> readAttributes(Path path, String s, LinkOption... array) throws IOException {
        String[] split = split(s);
        if (split[0].length() == 0) {
            throw new IllegalArgumentException(s);
        }
        DynamicFileAttributeView fileAttributeView = this.getFileAttributeView(path, split[0], array);
        if (fileAttributeView == null) {
            throw new UnsupportedOperationException("View '" + split[0] + "' not available");
        }
        return fileAttributeView.readAttributes(split[1].split(","));
    }
    
    abstract boolean implDelete(Path p0, boolean p1) throws IOException;
    
    @Override
    public final void delete(Path path) throws IOException {
        this.implDelete(path, true);
    }
    
    @Override
    public final boolean deleteIfExists(Path path) throws IOException {
        return this.implDelete(path, false);
    }
}
